const regFileExtension = /(?:\.([^.]+))?$/;

export class FileUtil {
  static getExtension(fileName: string): string | undefined {
    return regFileExtension.exec(fileName)[1];
  }

  static getExtensions(fileList: FileList): string[] {
    const extensions: string[] = [];
    // tslint:disable-next-line: prefer-for-of
    for (let i = 0; i < fileList.length; i++) {
      extensions.push(FileUtil.getExtension(fileList[i].name));
    }
    return extensions;
  }

  static fromBlobToDataUrl(blob: Blob): Promise<string | ArrayBuffer> {
    return new Promise<string | ArrayBuffer>((resolve, reject) => {
      const fileReader = new FileReader();
      fileReader.onload = () => {
        return resolve(fileReader.result);
      };
      fileReader.onerror = (event: ProgressEvent) => {
        fileReader.abort();
        return reject(fileReader.error);
      };
      fileReader.readAsDataURL(blob);
    });
  }

  static fromBlobToBuffer(blob: Blob): Promise<Buffer> {
    return new Promise<Buffer>((resolve, reject) => {
      const fileReader = new FileReader();
      fileReader.onload = () => {
        return resolve(Buffer.from(fileReader.result as ArrayBuffer));
      };
      fileReader.onerror = (event: ProgressEvent) => {
        fileReader.abort();
        return reject(fileReader.error);
      };
      fileReader.readAsArrayBuffer(blob);
    });
  }

  static fromBlobToString(blob: Blob): Promise<string> {
    return new Promise<string>((resolve, reject) => {
      const fileReader = new FileReader();
      fileReader.onload = () => {
        return resolve(fileReader.result.toString());
      };
      fileReader.onerror = (event: ProgressEvent) => {
        fileReader.abort();
        return reject(fileReader.error);
      };
      fileReader.readAsArrayBuffer(blob);
    });
  }
}
